load("suppMat.RData")

library(ez)
head(dRectPse_L)
str(dRectPse_L)

# viewpoint
#   position1: middle of short wall
#   position2: middle of long wall
# rectangularity
#   A (1:1 ratio)
#   B (1:2 ratio)
#   C (1:3 ratio)
# pse
#   raw PSE value
# pseDiffRelConst
#   PSE difference relative to constant stimulus
# pseDiffRel11:
#   PSE difference relative to 1:1 ratio

####################
# PSE difference

# Three-way interaction between culture, perspective and rectangularity
ezANOVA(data=dRectPse_L, dv=pseDiffRel11, wid=subjId, within=rectangularity,
        between=.(culture, viewpoint))

# The three-way interaction can be explained by a significant two-way interaction
# present for Germans but not for Koreans.

# Germans show a two-way interaction, p = .0041 or p = .0064 with correction
german <- dRectPse_L[dRectPse_L$culture=="german",]
german$subjId <- factor(german$subjId)
ezANOVA(data=german, dv=pseDiffRel11, wid=subjId, within=rectangularity,
        between=viewpoint)

# Not present in Korean data, p = .69
korean <- dRectPse_L[dRectPse_L$culture=="korean",]
korean$subjId <- factor(korean$subjId)
ezANOVA(data=korean, dv=pseDiffRel11, wid=subjId, within=rectangularity,
        between=viewpoint)

# Post-hoc, within culture, p = .0082, p = .0093
(t1 <- t.test(pseDiffRel11 ~ viewpoint, data=dRectPse_L[dRectPse_L$culture=="german" & dRectPse_L$rectangularity=="B",], var.equal=T))
(t2 <- t.test(pseDiffRel11 ~ viewpoint, data=dRectPse_L[dRectPse_L$culture=="german" & dRectPse_L$rectangularity=="C",], var.equal=T))

####################
# Raw PSE values

ezANOVA(data=dRectPse_L, dv=pse, wid=subjId, within=rectangularity,
        between=.(culture, viewpoint))

german <- dRectPse_L[dRectPse_L$culture=="german",]
german$subjId <- factor(german$subjId)
ezANOVA(data=german, dv=pse, wid=subjId, within=rectangularity,
        between=viewpoint)

korean <- dRectPse_L[dRectPse_L$culture=="korean",]
korean$subjId <- factor(korean$subjId)
ezANOVA(data=korean, dv=pse, wid=subjId, within=rectangularity,
        between=viewpoint)

# Post-hoc, within culture
(t1 <- t.test(pse ~ viewpoint, data=dRectPse_L[dRectPse_L$culture=="german" & dRectPse_L$rectangularity=="B",], var.equal=T))
(t2 <- t.test(pse ~ viewpoint, data=dRectPse_L[dRectPse_L$culture=="german" & dRectPse_L$rectangularity=="C",], var.equal=T))

####################
# Yaw rotation range

library(lme4)
# widthDepthRatioN
#   the numeric version of widthDepthRatio (3:1, 2:1, 1:1, 1:2, 1:3)
lmer1 <- lmer(yawRange ~ 1 + (1|subjId), data=dRectPse_L)
lmer2 <- lmer(yawRange ~ 1 + widthDepthRatioN + (1|subjId), data=dRectPse_L)
lmer3 <- lmer(yawRange ~ 1 + widthDepthRatioN + culture + (1|subjId), data=dRectPse_L)
lmer4 <- lmer(yawRange ~ 1 + widthDepthRatioN + culture + widthDepthRatioN:culture + (1|subjId), data=dRectPse_L)
anova(lmer1, lmer2, lmer3, lmer4)
summary(lmer4)
